==> how-to-cook-1.1.0.tgz: package/tips/advanced/高级专业术语.md <==
# 做菜专业术语

做菜和学习编程一样，首先得认识专业术语就好比学习基础语法，通过术语之间的组合方能完成一道菜。

【炒】古写作“煼(chǎo)”，是目前最基本的烹调方法之一；即将食物切成小件，连同调味料放入烧猛油的铁镬(huò)（锅）中迅速翻搅致熟的手法。

【炝】食物切好后，经沸水或热油的“灼”或“泡”等处理后，再在烧镬（锅）中爆入干辣椒和花椒油拌匀的烹调方法。

【炊】即利用蒸、煮等将食物致熟的方法。多见冠名在潮州菜中。

【煮】最简单的烹调方法之一；在镬（锅）中用适量的沸水或汤水以及调味料将食物致熟的烹调方法。

【煎】烧热铁镬（锅），放入少许生油，然后将食物平滩紧贴在镬中，利用慢火热油使食物的表面呈金黄色及致熟的烹调方法。

【爆】利用热镬（锅）热油，攒入适量调好的汁酱或汤水，使镬中的小件食物快速致熟又赋入香气的烹调方法。

【炸(zhà)】古写作“煠(zhá)”，最常用的烹调方法之一；指将食物放入大量的热油中致熟至脆的烹调手法。

【烚(xiá)】古写作“煠”，利用大量的沸水将肉质较韧的食物在炉火上炊软炊熟的加工方法。

【滚】利用大量的沸水的涌动将食物窳(yǔ)味带出的加工方法。

【氽(tǔn)】北方烹调术语，古为“川”；近乎粤菜的“渌(lù)”，即将加工成丸状或片状的食物在沸水中致熟后，捞起入碗中，再添入沸汤的烹调方法。

【灼(zhuó)】北方写作“焯(chāo)”；是指食物切成薄片等，利用沸水迅速至熟再蘸(zhàn)上酱料而吃的烹调方法。

【炟(dá)】将蔬菜放入添有枧(jiǎn)水或生油的沸中用慢火煮透，使成品软并保持翠绿的加工方法。

【涮(shuàn)】北方烹调术语；将切成薄片的食物放入辣汤中致熟再蘸上酱料而吃的烹调方法。

【煀(kuò)】古时写作“爩(yù)”；指将食物直接放入镬（锅）中或瓦罉（煲）中，加入大量姜葱等香料料头，盖上盖，利用大量的香料料头至香及达到成熟的烹调方法。

【焗(jú)】利用灼热的粗盐等将用锡纸或玉扣纸等包封好的食物在密封的条件下致熟的烹调方法。

【焖(mèn)】北方烹调法；指质韧的食物放入镬（锅）中，加入适量的汤水，盖上盖并利用文火炊软及致熟的烹调方法。

【炆(wén)】近乎北方烹调法的“烧”，故有“南炆北烧”之说；指质韧的食物放入镬（锅）中，加入适量的汤水，利用文火炊软及致熟的烹调方法。

【烩(huì)】用适量的汤水将多种肉料和蔬菜一同炊煮的烹调方法。

【蒸】利用水蒸汽的热力使食物致熟的烹调方法。

【炖(dùn)】食物加入清水或汤水，放入有盖的容器中，盖盖，再利用水蒸汽的热力致熟并得出汤水的烹调方法。北方菜系是指用大量汤水及文火将食物炊软炊熟的烹调方法。

【扣】食物经调味及预加工后，整齐排放入扣碗之中隔水蒸熟，然后主料覆扣入碟中再泼上用原汁勾好的琉璃的烹调方法。

【煲(bāo)】将食物放入大量的清水，置在炉火上慢火炊熟并得出汤水的烹调方法。

【熬】利用慢火长时间地将肉料鲜味融入汤水中并使汤水浓缩的加工方法。

【靠(kào)】利用浓味的原料和鲜汤，利用文火和通过较长的时间将鲜味赋入另一种乏味主料中的加工或烹调方法。

【煨(wēi)】古作埋入炭灰至熟方法。今指利用姜葱和汤水使食物入味及辟去食物本身的异味的加工方法。北方菜系又指食物连同汤水放入密封的瓦坛中，在文火中致熟的烹调方法。

【焐(wù)】替代“煨”的古意，指食物经腌制后，用荷叶等包裹，再用湿泥或面图裹封，置入炭火中致熟的烹调方法。

【烘(hōng)】点心或食物调好味或加工好后置入烘炉中致熟的烹调方法。

【煸(biān)】同煏(bì)，旧讹写作“鞭”或“火便”，近乎“熯(rǎn)”，是指将食物放入热镬（锅）中，不断地翻炒，使食物中水分略熯干而辟除窳味的加工方法；或经此而收浓鲜味而吃的烹调方法。

【溜(liū)】北方烹调术语，近乎粤菜的“打芡(qiàn)”，即酸甜的汁水用生粉勾芡令酥炸过的食物滑嫩可口的烹调方法。

【羹(gēng)】古老的烹调法之一，是指切制成丁的食物用沸汤煮后，除除加入湿生粉，使汤水溜成糊状的烹调方法。

【攒(zǎn)】曾写作“溅”或“灒(zàn)”等，分“攒油”或“攒酒”；前者是指将烧沸的热油泼洒在蒸熟的食物上以辟腥增滑的手法；后者是指将绍酒泼洒入正在烹煮的食物上，令食物更有“镬(huò)气”的手法。

【烫】指用沸水收紧肉料表皮的加工方法。北方常见是指将切片、切件的原料在沸汤或辣汤中致熟的烹调方法。

【烧】古时的“炙(zhì)”，粤菜是指将食物放在炭火或明火上致熟的烹调方法。现北方菜系是指通过慢火将汁水略收干并将食物炊熟的烹调方法。

【烤】北方菜系用来替代“烧”的旧意，故有“南烧北烤”之说。是指食物置在明火上致熟的烹调方法。

【卤(lǔ)】利用生抽与香料药材调好的“卤水汁”使食物致熟或令其入味的烹调方法。

【酱(jiàng)】利用大量的汁酱或生抽入味或致熟的烹调方法。

【浸】利用大量的沸水或汤水以“菊花心”为度的热力在一定时间内将食物致熟的烹调方法。类似北方的“氽(tǔn)”，即物料灼熟后，再舀(yǎo)入过面的汤水而食的烹调方法。

【风】常年将腌制好的食物吊挂在通风的地方，让其自然阴干或风干的加工方法。

【腊】在农历十二月前后将腌好的食物吊挂在通风的地方，让其自然阴干或风干的加工方法。

【烟】茶味或香料药材在密封情况下点燃，让食物赋入其香喷烟味的烹调方法。

【熏】旧写作“熏”，有“干熏”与“湿熏”之分，“干熏”类似“烟”；“湿熏”是食物用鲜花或绍酒等赋入香味的烹调方法。

【糟(zāo)】将食物放入酒糟之中入味或致熟的烹调方法。

【醉】利用大量的烧酒入味或致熟的烹调方法。

【甑(zèng)】古时的“蒸”；将食物斩件调味后放入瓦钵(bō)之中，再利用较强的蒸气致熟的烹调方法。

【冻】又称“水晶”，是指将煮烂的食物加入琼脂或猪皮等再煮成羹，然后置入冰箱待其冰冻凝结而吃的烹调方法。

【飞水】将食物投入沸水中过一过水致半熟而迅速捞起，为继后的烹调提供良好前沿基础的加工方法。

【冰浸】食物切成丝后，迅速投入冰水之中，令食物有爽脆效果的一种加工烹调方法。此法源于曰本。

【拨丝】食物上浆油炸后，放入煮溶的糖浆中拌匀，使食物夹起时能拉出细丝的烹调方法。

【挂霜】食物经油炸后，放入煮溶的糖浆中拌匀打散或直接洒入糖粉的烹调方法。

【椒盐】食物经油炸后致熟和干身后，再用事先用椒米和精盐配好的“椒盐”翻炒拌匀的烹调方法。

【油泡】利用大量的热油，迅速地将食物致熟的烹调方法。

【走油】又称“拖油”“走油”“跑油”；是指将加工好的原料放入滚油之中迅速拖过，为继后的烹调提供前沿基础的加工方法。

【火焰】将生猛新鲜的海鲜放入玻璃器皿内，利用点燃高度数的白酒产生的热力致熟的烹调方法。

【啫(zé)啫(zé)】食物及姜葱等放入烧致极热的瓦罉（煲），使食物发出“啫啫”声音和喷出香气的烹调方法。

【串烧】肉料切片腌制好后，用竹签串丐，放入热油中“泡”而食的烹调方法。或肉料切片后，用铁钎串起，放入炭炎上烧熟，再撒上孜(zī)然等味料的烹调方法。

【铁板】原是西式烹调方法；即指食物“走油”后，连同以洋葱为主的香料料头和汁酱，放入烧致极热的铁板中致熟和致令食物喷香的烹调方法。

【桑拿】又称“石烹”等；食物经拖油后，投入烧至灼热的石子（多是雨花石）上，再攒入调好的汁酱或汤水，利用蒸气将食物至熟或喷出香气的烹调方法。

【煎封】北方又称“煎烹”，一般适合于鱼类较多；即将鱼类用调味品腌过后，用热油慢火煎透，再封上料头芡(qiàn)使透味的烹调方法。

【窝贴】属“半煎炸法”，即将腌过的肉料上好“窝贴浆”贴在肥肉上，利用“猛镬阴油”令肉料一面酥脆而一面软滑的烹调方法 。

【窝塌(tā)】将腌好的食物上好“蛋粉浆”，利用先煎后炸的手法，使食物煎熟，然后再加入调好味的鲜汤再煮透的烹调方法。

【软煎】属“半煎炸法”，即将腌过的肉料拌上“蛋粉浆”，利用先煎后炸的手法使肉料致熟，然后切件淋上酱汁的烹调方法。

【蛋煎】肉料先用“飞水”或“油泡”的方法预熟，再放入调好味的鸡蛋浆内拌匀，然后用文火将肉料蛋浆底面煎至金黄色的烹调方法。

【吉列】为英文 CUTLET 的译音；即将食物上蛋浆后，粘上面包糠，再用热油浸炸的烹调方法。此做法源于西厨。

【酥炸】食物用调味品腌过后，先上湿粉浆，再拍上干生粉，再用热油炸熟，然后捞入酱汁的烹调方法。

【火锅】又称“涮锅”，广东称“打边炉”，即将新鲜肉料“片”、“切”成薄片，或肉料挞成丸、球、馅等，连同蔬菜等送到客人边，让客人自行放入滚水或滚汤中烹熟的食法。

【汽锅】将肉料腌制后，连同药材，放入煮滚调味汤水的一种特制的“气锅”中，细熬而食的烹调方法。

【凉拌】将熟食食物或蔬果改切好后，加入调味料和拌均匀的烹调方法。

【鱼生】将新鲜生猛水产去血后，改切薄片，拌上姜丝、葱丝、薄脆、柠檬丝等，再蘸上生抽而吃的烹调方法。

【刺身】原是曰本料理的做法，原指生食肉片，经中国菜引用指将鲜活的水产或海产去鳞净血，薄切成片，滴入柠檬汁，蘸上曰本芥(jiè)辣而吃的烹调方法。

【竹筒】古称“熷(zēng)”，指用竹筒为器皿，再经“烤”“烧”“蒸”“炖(dùn)”等方法将食物致熟的烹调方法。

【蜜汁】指将白糖、蜂蜜、麦芽糖等化成浓汁，放入加工好的原料，经“熬”、“蒸”等方法使质地软糯(nuò)、甜味渗透、润透糖汁的烹调方法。

【焯(chāo)水】又称“出水”，是将原料置于开水或冷水锅中进行初步熟处理的一种方法。

【过油】用油为传热介质对烹饪原料进行初步熟处理的方法。小型原料从温油走过又称“滑油”；大型原料从旺油中走过又称“走油。

【挂糊】烹饪前将原料均匀裹上一层糊液的工艺。

【上浆】用淀粉、鸡蛋、盐等与原料一起调拌，使原料外层裹上一层薄薄浆液的工艺。

【上劲】将加工成茸(róng)泥(ní)末(mò)的动物性原料加精盐、水、淀粉及其他辅料后反复搅拌，使之达到色泽发亮、肉质细嫩、入水不沉、不散状态的一种加工方法。

【勾(gōu)芡（qiàn)】在烹饪过程中向锅中加入淀粉水溶液，使菜肴汤汁具有一定浓稠度的工艺。/又称“着腻”、“着芡”、“拢(lǒng)芡(qiàn)”。

【温油】俗称三至四成，温度一般在 70℃~100℃。

【热油】俗称五至六成，温度一般在 110℃~170℃。

【旺油】俗称七至八成，温度一般在 180℃~220℃。

【滑锅】将锅烧热，淋少许油把锅滑遍，再倒出油的一种方法。

【炝锅】又称“炸锅”，是指将姜、葱、辣椒末或其他带有香味的调料放入烧热的底油,锅中煸炒出香味，再及时下菜料的一种方法。

【高汤】又称“清汤”、“上汤”、“顶汤”，是指用猪骨、鸡骨、鸭架、碎肉头等原料熬制好的毛汤，加入和成稀糊状的、未加盐的鸡茸或肉茸处理，使之清澈如水、味浓而鲜的一种汤料。

【奶汤】又称“白汤”，原料加清水煨制而成的色泽乳白的汤。

==> how-to-cook-1.2.0.tgz: package/tips/advanced/高级专业术语.md <==
# 做菜专业术语

做菜和学习编程一样，首先得认识专业术语就好比学习基础语法，通过术语之间的组合方能完成一道菜。

【炒(chǎo)】古写作“煼(chǎo)”，是目前最基本的烹调方法之一；即将食物切成小件，连同调味料放入烧猛油的铁镬(huò)（锅）中迅速翻搅致熟的手法。

【炝(qiàng)】食物切好后，经沸水或热油的“灼”或“泡”等处理后，再在烧镬（锅）中爆入干辣椒和花椒油拌匀的烹调方法。

【炊(chuī)】即利用蒸、煮等将食物致熟的方法。多见冠名在潮州菜中。

【煮(zhǔ)】最简单的烹调方法之一；在镬（锅）中用适量的沸水或汤水以及调味料将食物致熟的烹调方法。

【煎(jiān)】烧热铁镬（锅），放入少许生油，然后将食物平滩紧贴在镬中，利用慢火热油使食物的表面呈金黄色及致熟的烹调方法。

【爆(bào)】利用热镬（锅）热油，攒入适量调好的汁酱或汤水，使镬中的小件食物快速致熟又赋入香气的烹调方法。

【炸(zhá)】古写作“煠(zhá)”，最常用的烹调方法之一；指将食物放入大量的热油中致熟至脆的烹调手法。

【烚(xiá)】古写作“煠”，利用大量的沸水将肉质较韧的食物在炉火上炊软炊熟的加工方法。

【滚(gǔn)】利用大量的沸水的涌动将食物窳(yǔ)味带出的加工方法。

【汆(cuān)】北方烹调术语，古为“川”；近乎粤菜的“渌(lù)”，即将加工成丸状或片状的食物在沸水中致熟后，捞起入碗中，再添入沸汤的烹调方法。

【灼(zhuó)】北方写作“焯(chāo)”；是指食物切成薄片等，利用沸水迅速至熟再蘸(zhàn)上酱料而吃的烹调方法。

【炟(dá)】将蔬菜放入添有枧(jiǎn)水或生油的沸中用慢火煮透，使成品软并保持翠绿的加工方法。

【涮(shuàn)】北方烹调术语；将切成薄片的食物放入辣汤中致熟再蘸上酱料而吃的烹调方法。

【煀(kuò)】古时写作“爩(yù)”；指将食物直接放入镬（锅）中或瓦罉（煲）中，加入大量姜葱等香料料头，盖上盖，利用大量的香料料头至香及达到成熟的烹调方法。

【焗(jú)】利用灼热的粗盐等将用锡纸或玉扣纸等包封好的食物在密封的条件下致熟的烹调方法。

【焖(mèn)】北方烹调法；指质韧的食物放入镬（锅）中，加入适量的汤水，盖上盖并利用文火炊软及致熟的烹调方法。

【炆(wén)】近乎北方烹调法的“烧”，故有“南炆北烧”之说；指质韧的食物放入镬（锅）中，加入适量的汤水，利用文火炊软及致熟的烹调方法。

【烩(huì)】用适量的汤水将多种肉料和蔬菜一同炊煮的烹调方法。

【蒸(zhēng)】利用水蒸汽的热力使食物致熟的烹调方法。

【炖(dùn)】食物加入清水或汤水，放入有盖的容器中，盖盖，再利用水蒸汽的热力致熟并得出汤水的烹调方法。北方菜系是指用大量汤水及文火将食物炊软炊熟的烹调方法。

【扣(kòu)】食物经调味及预加工后，整齐排放入扣碗之中隔水蒸熟，然后主料覆扣入碟中再泼上用原汁勾好的琉璃的烹调方法。

【煲(bāo)】将食物放入大量的清水，置在炉火上慢火炊熟并得出汤水的烹调方法。

【熬(áo)】利用慢火长时间地将肉料鲜味融入汤水中并使汤水浓缩的加工方法。

【靠(kào)】利用浓味的原料和鲜汤，利用文火和通过较长的时间将鲜味赋入另一种乏味主料中的加工或烹调方法。

【煨(wēi)】古作埋入炭灰致熟方法。今指利用姜葱和汤水使食物入味及辟去食物本身的异味的加工方法。北方菜系又指食物连同汤水放入密封的瓦坛中，在文火中致熟的烹调方法。

【焐(wù)】替代“煨”的古意，指食物经腌制后，用荷叶等包裹，再用湿泥或面图裹封，置入炭火中致熟的烹调方法。

【烘(hōng)】点心或食物调好味或加工好后置入烘炉中致熟的烹调方法。

【煸(biān)】同煏(bì)，旧讹写作“鞭”或“火便”，近乎“熯(rǎn)”，是指将食物放入热镬（锅）中，不断地翻炒，使食物中水分略熯干而辟除窳味的加工方法；或经此而收浓鲜味而吃的烹调方法。

【溜(liū)】北方烹调术语，近乎粤菜的“打芡(qiàn)”，即酸甜的汁水用生粉勾芡令酥炸过的食物滑嫩可口的烹调方法。

【羹(gēng)】古老的烹调法之一，是指切制成丁的食物用沸汤煮后，除除加入湿生粉，使汤水溜成糊状的烹调方法。

【攒(zǎn)】曾写作“溅”或“灒(zàn)”等，分“攒油”或“攒酒”；前者是指将烧沸的热油泼洒在蒸熟的食物上以辟腥增滑的手法；后者是指将绍酒泼洒入正在烹煮的食物上，令食物更有“镬(huò)气”的手法。

【烫(tàng)】指用沸水收紧肉料表皮的加工方法。北方常见是指将切片、切件的原料在沸汤或辣汤中致熟的烹调方法。

【烧(shāo)】古时的“炙(zhì)”，粤菜是指将食物放在炭火或明火上致熟的烹调方法。现北方菜系是指通过慢火将汁水略收干并将食物炊熟的烹调方法。

【烤(kǎo)】北方菜系用来替代“烧”的旧意，故有“南烧北烤”之说。是指食物置在明火上致熟的烹调方法。

【卤(lǔ)】利用生抽与香料药材调好的“卤水汁”使食物致熟或令其入味的烹调方法。

【酱(jiàng)】利用大量的汁酱或生抽入味或致熟的烹调方法。

【浸(jìn)】利用大量的沸水或汤水以“菊花心”为度的热力在一定时间内将食物致熟的烹调方法。类似北方的“氽(tǔn)”，即物料灼熟后，再舀(yǎo)入过面的汤水而食的烹调方法。

【风(fēng)】常年将腌制好的食物吊挂在通风的地方，让其自然阴干或风干的加工方法。

【腊(là)】在农历十二月前后将腌好的食物吊挂在通风的地方，让其自然阴干或风干的加工方法。

【烟(yān)】茶味或香料药材在密封情况下点燃，让食物赋入其香喷烟味的烹调方法。

【熏(xūn)】旧写作“熏”，有“干熏”与“湿熏”之分，“干熏”类似“烟”；“湿熏”是食物用鲜花或绍酒等赋入香味的烹调方法。

【糟(zāo)】将食物放入酒糟之中入味或致熟的烹调方法。

【醉(zuì)】利用大量的烧酒入味或致熟的烹调方法。

【甑(zèng)】古时的“蒸”；将食物斩件调味后放入瓦钵(bō)之中，再利用较强的蒸气致熟的烹调方法。

【冻(dòng)】又称“水晶”，是指将煮烂的食物加入琼脂或猪皮等再煮成羹，然后置入冰箱待其冰冻凝结而吃的烹调方法。

【飞水】将食物投入沸水中过一过水致半熟而迅速捞起，为继后的烹调提供良好前沿基础的加工方法。

【冰浸】食物切成丝后，迅速投入冰水之中，令食物有爽脆效果的一种加工烹调方法。此法源于日本。

【拨丝】食物上浆油炸后，放入煮溶的糖浆中拌匀，使食物夹起时能拉出细丝的烹调方法。

【挂霜】食物经油炸后，放入煮溶的糖浆中拌匀打散或直接洒入糖粉的烹调方法。

【椒盐】食物经油炸后致熟和干身后，再用事先用椒米和精盐配好的“椒盐”翻炒拌匀的烹调方法。

【油泡】利用大量的热油，迅速地将食物致熟的烹调方法。

【走油】又称“拖油”“走油”“跑油”；是指将加工好的原料放入滚油之中迅速拖过，为继后的烹调提供前沿基础的加工方法。

【火焰】将生猛新鲜的海鲜放入玻璃器皿内，利用点燃高度数的白酒产生的热力致熟的烹调方法。

【啫(zé)啫(zé)】食物及姜葱等放入烧至极热的瓦罉（煲），使食物发出“啫啫”声音和喷出香气的烹调方法。

【串烧】肉料切片腌制好后，用竹签串起，放入热油中“泡”而食的烹调方法。或肉料切片后，用铁钎串起，放入炭火上烧熟，再撒上孜(zī)然等味料的烹调方法。

【铁板】原是西式烹调方法；即指食物“走油”后，连同以洋葱为主的香料料头和汁酱，放入烧致极热的铁板中致熟和致令食物喷香的烹调方法。

【桑拿】又称“石烹”等；食物经拖油后，投入烧至灼热的石子（多是雨花石）上，再攒入调好的汁酱或汤水，利用蒸气将食物致熟或喷出香气的烹调方法。

【煎封】北方又称“煎烹”，一般适合于鱼类较多；即将鱼类用调味品腌过后，用热油慢火煎透，再封上料头芡(qiàn)使透味的烹调方法。

【窝贴】属“半煎炸法”，即将腌过的肉料上好“窝贴浆”贴在肥肉上，利用“猛镬阴油”令肉料一面酥脆而一面软滑的烹调方法 。

【窝塌(tā)】将腌好的食物上好“蛋粉浆”，利用先煎后炸的手法，使食物煎熟，然后再加入调好味的鲜汤再煮透的烹调方法。

【软煎】属“半煎炸法”，即将腌过的肉料拌上“蛋粉浆”，利用先煎后炸的手法使肉料致熟，然后切件淋上酱汁的烹调方法。

【蛋煎】肉料先用“飞水”或“油泡”的方法预熟，再放入调好味的鸡蛋浆内拌匀，然后用文火将肉料蛋浆底面煎至金黄色的烹调方法。

【吉列】为英文 CUTLET 的译音；即将食物上蛋浆后，粘上面包糠，再用热油浸炸的烹调方法。此做法源于西厨。

【酥炸】食物用调味品腌过后，先上湿粉浆，再拍上干生粉，再用热油炸熟，然后捞入酱汁的烹调方法。

【火锅】又称“涮锅”，广东称“打边炉”，即将新鲜肉料“片”、“切”成薄片，或肉料挞成丸、球、馅等，连同蔬菜等送到客人边，让客人自行放入滚水或滚汤中烹熟的食法。

【汽锅】将肉料腌制后，连同药材，放入煮滚调味汤水的一种特制的“气锅”中，细熬而食的烹调方法。

【凉拌】将熟食食物或蔬果改切好后，加入调味料和拌均匀的烹调方法。

【鱼生】将新鲜生猛水产去血后，改切薄片，拌上姜丝、葱丝、薄脆、柠檬丝等，再蘸上生抽而吃的烹调方法。

【刺身】原是曰本料理的做法，原指生食肉片，经中国菜引用指将鲜活的水产或海产去鳞净血，薄切成片，滴入柠檬汁，蘸上曰本芥(jiè)辣而吃的烹调方法。

【竹筒】古称“熷(zēng)”，指用竹筒为器皿，再经“烤”“烧”“蒸”“炖(dùn)”等方法将食物致熟的烹调方法。

【蜜汁】指将白糖、蜂蜜、麦芽糖等化成浓汁，放入加工好的原料，经“熬”、“蒸”等方法使质地软糯(nuò)、甜味渗透、润透糖汁的烹调方法。

【焯(chāo)水】又称“出水”，是将原料置于开水或冷水锅中进行初步熟处理的一种方法。

【过油】用油为传热介质对烹饪原料进行初步熟处理的方法。小型原料从温油走过又称“滑油”；大型原料从旺油中走过又称“走油”。

【挂糊】烹饪前将原料均匀裹上一层糊液的工艺。

【上浆】用淀粉、鸡蛋、盐等与原料一起调拌，使原料外层裹上一层薄薄浆液的工艺。

【上劲】将加工成茸(róng)泥(ní)末(mò)的动物性原料加精盐、水、淀粉及其他辅料后反复搅拌，使之达到色泽发亮、肉质细嫩、入水不沉、不散状态的一种加工方法。

【勾(gōu)芡(qiàn)】在烹饪过程中向锅中加入淀粉水溶液，使菜肴汤汁具有一定浓稠度的工艺。又称“着腻”、“着芡”、“拢(lǒng)芡(qiàn)”。

【温油】俗称三至四成，温度一般在 70℃~100℃。

【热油】俗称五至六成，温度一般在 110℃~170℃。

【旺油】俗称七至八成，温度一般在 180℃~220℃。

【滑锅】将锅烧热，淋少许油把锅滑遍，再倒出油的一种方法。

【炝锅】又称“炸锅”，是指将姜、葱、辣椒末或其他带有香味的调料放入烧热的底油,锅中煸炒出香味，再及时下菜料的一种方法。

【高汤】又称“清汤”、“上汤”、“顶汤”，是指用猪骨、鸡骨、鸭架、碎肉头等原料熬制好的毛汤，加入和成稀糊状的、未加盐的鸡茸或肉茸处理，使之清澈如水、味浓而鲜的一种汤料。

【奶汤】又称“白汤”，原料加清水煨制而成的色泽乳白的汤。
